{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Subworkflow that runs cnvkit in single sample mode and returns a vcf file",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "cnvkit.vcf",
                    "id": "#main/cnvkit_vcf_name"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/diagram"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/drop_low_coverage"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#main/fasta_reference"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/male_reference"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/method/hybrid",
                                "#main/method/amplicon",
                                "#main/method/wgs"
                            ]
                        }
                    ],
                    "id": "#main/method"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/reference_cnn"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/scatter_plot"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/segment_filter/ampdel",
                                "#main/segment_filter/ci",
                                "#main/segment_filter/cn",
                                "#main/segment_filter/sem"
                            ]
                        }
                    ],
                    "id": "#main/segment_filter"
                },
                {
                    "type": "File",
                    "id": "#main/tumor_bam"
                }
            ],
            "steps": [
                {
                    "run": "#cnvkit_vcf_export.cwl",
                    "in": [
                        {
                            "source": "#main/cnvkit_main/tumor_bin_level_ratios",
                            "id": "#main/cns_to_vcf/cnr_file"
                        },
                        {
                            "source": "#main/cnvkit_main/tumor_segmented_ratios",
                            "id": "#main/cns_to_vcf/cns_file"
                        },
                        {
                            "source": "#main/male_reference",
                            "id": "#main/cns_to_vcf/male_reference"
                        },
                        {
                            "source": "#main/cnvkit_vcf_name",
                            "id": "#main/cns_to_vcf/output_name"
                        },
                        {
                            "source": "#main/segment_filter",
                            "id": "#main/cns_to_vcf/segment_filter"
                        }
                    ],
                    "out": [
                        "#main/cns_to_vcf/cnvkit_vcf"
                    ],
                    "id": "#main/cns_to_vcf"
                },
                {
                    "run": "#cnvkit_batch.cwl",
                    "in": [
                        {
                            "source": "#main/diagram",
                            "id": "#main/cnvkit_main/diagram"
                        },
                        {
                            "source": "#main/drop_low_coverage",
                            "id": "#main/cnvkit_main/drop_low_coverage"
                        },
                        {
                            "source": "#main/male_reference",
                            "id": "#main/cnvkit_main/male_reference"
                        },
                        {
                            "source": "#main/method",
                            "id": "#main/cnvkit_main/method"
                        },
                        {
                            "source": [
                                "#main/reference_cnn",
                                "#main/fasta_reference"
                            ],
                            "valueFrom": "${\n  var cnn = self[0];\n  var fasta = self[1];\n  return {'cnn_file': cnn, 'fasta_file': fasta};\n}\n",
                            "id": "#main/cnvkit_main/reference"
                        },
                        {
                            "source": "#main/scatter_plot",
                            "id": "#main/cnvkit_main/scatter_plot"
                        },
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/cnvkit_main/tumor_bam"
                        }
                    ],
                    "out": [
                        "#main/cnvkit_main/cn_diagram",
                        "#main/cnvkit_main/cn_scatter_plot",
                        "#main/cnvkit_main/tumor_antitarget_coverage",
                        "#main/cnvkit_main/tumor_target_coverage",
                        "#main/cnvkit_main/tumor_bin_level_ratios",
                        "#main/cnvkit_main/tumor_segmented_ratios"
                    ],
                    "id": "#main/cnvkit_main"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/cnvkit_main/cn_diagram",
                    "id": "#main/cn_diagram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/cnvkit_main/cn_scatter_plot",
                    "id": "#main/cn_scatter_plot"
                },
                {
                    "type": "File",
                    "outputSource": "#main/cns_to_vcf/cnvkit_vcf",
                    "id": "#main/cnvkit_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/cnvkit_main/tumor_antitarget_coverage",
                    "id": "#main/tumor_antitarget_coverage"
                },
                {
                    "type": "File",
                    "outputSource": "#main/cnvkit_main/tumor_bin_level_ratios",
                    "id": "#main/tumor_bin_level_ratios"
                },
                {
                    "type": "File",
                    "outputSource": "#main/cnvkit_main/tumor_segmented_ratios",
                    "id": "#main/tumor_segmented_ratios"
                },
                {
                    "type": "File",
                    "outputSource": "#main/cnvkit_main/tumor_target_coverage",
                    "id": "#main/tumor_target_coverage"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/usr/bin/python",
                "/usr/local/bin/cnvkit.py",
                "batch"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "etal/cnvkit:0.9.5"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 4000,
                    "tmpdirMin": 10000
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$((inputs.reference.hasOwnProperty('cnn_file'))? null : '--normal')"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--access"
                    },
                    "doc": "Regions of accessible sequence on chromosomes (.bed), as output by the 'access' command",
                    "id": "#cnvkit_batch.cwl/access"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--targets"
                    },
                    "id": "#cnvkit_batch.cwl/bait_intervals"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--diagram"
                    },
                    "doc": "Create an ideogram of copy ratios on chromosomes as a PDF",
                    "id": "#cnvkit_batch.cwl/diagram"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--drop-low-coverage"
                    },
                    "doc": "Drop very-low-coverage bins before segmentation to avoid false-positive deletions in poor-quality tumor samples",
                    "id": "#cnvkit_batch.cwl/drop_low_coverage"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "--male-reference"
                    },
                    "doc": "Use or assume a male reference (i.e. female samples will have +1 log-CNR of chrX; otherwise male samples would have -1 chrX)",
                    "id": "#cnvkit_batch.cwl/male_reference"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#cnvkit_batch.cwl/method/hybrid",
                                "#cnvkit_batch.cwl/method/amplicon",
                                "#cnvkit_batch.cwl/method/wgs"
                            ]
                        }
                    ],
                    "default": "hybrid",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--method"
                    },
                    "doc": "Sequencing protocol used for input data",
                    "id": "#cnvkit_batch.cwl/method"
                },
                {
                    "type": [
                        {
                            "type": "record",
                            "name": "#cnvkit_batch.cwl/reference/cnn_file",
                            "fields": [
                                {
                                    "type": "File",
                                    "inputBinding": {
                                        "position": 2,
                                        "prefix": "--reference"
                                    },
                                    "doc": "Previously generated reference.cnn file",
                                    "name": "#cnvkit_batch.cwl/reference/cnn_file/cnn_file"
                                }
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#cnvkit_batch.cwl/reference/fasta_file",
                            "fields": [
                                {
                                    "type": [
                                        "string",
                                        "File"
                                    ],
                                    "inputBinding": {
                                        "position": 2,
                                        "prefix": "--fasta"
                                    },
                                    "name": "#cnvkit_batch.cwl/reference/fasta_file/fasta_file"
                                },
                                {
                                    "type": [
                                        "null",
                                        "File"
                                    ],
                                    "inputBinding": {
                                        "position": 1
                                    },
                                    "doc": "Normal samples (.bam) used to construct the pooled, paired, or flat reference. If this option is used but no filenames are given, a 'flat' reference will be built. Otherwise, all filenames following this option will be used.",
                                    "name": "#cnvkit_batch.cwl/reference/fasta_file/normal_bam"
                                }
                            ]
                        }
                    ],
                    "id": "#cnvkit_batch.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--scatter"
                    },
                    "doc": "Create a whole-genome copy ratio profile as a PDF scatter plot",
                    "id": "#cnvkit_batch.cwl/scatter_plot"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--target-avg-size"
                    },
                    "doc": "Average size of split target bins (results are approximate)",
                    "id": "#cnvkit_batch.cwl/target_average_size"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#cnvkit_batch.cwl/tumor_bam"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.tumor_bam.nameroot)-diagram.pdf"
                    },
                    "id": "#cnvkit_batch.cwl/cn_diagram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.tumor_bam.nameroot)-scatter.pdf"
                    },
                    "id": "#cnvkit_batch.cwl/cn_scatter_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${  \n    var glob_base = \".antitarget.bed\";\n    if (inputs.bait_intervals) {\n        glob_base = inputs.bait_intervals.nameroot + glob_base;\n    }   \n    return glob_base;\n}  \n"
                    },
                    "id": "#cnvkit_batch.cwl/intervals_antitarget"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n    var glob_base = \".target.bed\";\n    if (inputs.bait_intervals) {\n        glob_base = inputs.bait_intervals.nameroot + glob_base;\n    }\n    return glob_base;\n}\n"
                    },
                    "id": "#cnvkit_batch.cwl/intervals_target"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n    var glob_base = \".antitargetcoverage.cnn\";\n    if (inputs.normal_bam) {\n        glob_base = inputs.normal_bam.nameroot + glob_base;\n    }\n    return glob_base;\n}\n"
                    },
                    "id": "#cnvkit_batch.cwl/normal_antitarget_coverage"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "${\n    var glob_base = \".targetcoverage.cnn\";\n    if (inputs.normal_bam) {\n        glob_base = inputs.normal_bam.nameroot + glob_base;\n    }\n    return glob_base;\n}\n"
                    },
                    "id": "#cnvkit_batch.cwl/normal_target_coverage"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "reference.cnn"
                    },
                    "id": "#cnvkit_batch.cwl/reference_coverage"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.tumor_bam.nameroot).antitargetcoverage.cnn"
                    },
                    "id": "#cnvkit_batch.cwl/tumor_antitarget_coverage"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.tumor_bam.nameroot).cnr"
                    },
                    "id": "#cnvkit_batch.cwl/tumor_bin_level_ratios"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.tumor_bam.nameroot).cns"
                    },
                    "id": "#cnvkit_batch.cwl/tumor_segmented_ratios"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.tumor_bam.nameroot).targetcoverage.cnn"
                    },
                    "id": "#cnvkit_batch.cwl/tumor_target_coverage"
                }
            ],
            "id": "#cnvkit_batch.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Convert default cnvkit .cns output to standard vcf format",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "etal/cnvkit:0.9.5"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "/usr/bin/python",
                "/usr/local/bin/cnvkit.py",
                "call"
            ],
            "arguments": [
                {
                    "position": -1,
                    "valueFrom": "$(inputs.male_reference)",
                    "prefix": "-y"
                },
                "-o",
                "adjusted.tumor.cns",
                {
                    "shellQuote": false,
                    "valueFrom": "&&"
                },
                "/usr/bin/python",
                "/usr/local/bin/cnvkit.py",
                "export",
                "vcf",
                "adjusted.tumor.cns"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--cnr"
                    },
                    "id": "#cnvkit_vcf_export.cwl/cnr_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#cnvkit_vcf_export.cwl/cns_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-y"
                    },
                    "id": "#cnvkit_vcf_export.cwl/male_reference"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-o"
                    },
                    "id": "#cnvkit_vcf_export.cwl/output_name"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#cnvkit_vcf_export.cwl/segment_filter/ampdel",
                                "#cnvkit_vcf_export.cwl/segment_filter/ci",
                                "#cnvkit_vcf_export.cwl/segment_filter/cn",
                                "#cnvkit_vcf_export.cwl/segment_filter/sem"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": -3,
                        "prefix": "--filter"
                    },
                    "doc": "method for filtering/merging neighboring copy number segments",
                    "id": "#cnvkit_vcf_export.cwl/segment_filter"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#cnvkit_vcf_export.cwl/cnvkit_vcf"
                }
            ],
            "id": "#cnvkit_vcf_export.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
